@@ -101,7 +101,7 @@ prop(~ rbinom(1000, prob = 0.5, size = 428) >= 240)
 xpbinom(239, prob = 0.5, size = 428)
 
 ## -------------------------------------------------------------------
-binom.test(x = 240, n = 248)
+binom.test(x = 240, n = 428)
 
 ## ----coinflip-------------------------------------------------------
 do(1) * rflip(428)
@@ -149,7 +149,7 @@ quantiles
 
 ## ----cor, fig.width=4, fig.height=2, tidy=FALSE---------------------
 Mustangs.hist <- mutate(Mustangs.cor.boot, 
-  colorval = cut(cor, c(-Inf, quantiles$quantile, Inf),
+  colorval = cut(cor, c(-Inf, quantiles, Inf),
     labels = c("Lower", "Middle", "Upper")))
 gf_histogram(~ cor, data = Mustangs.hist, fill = ~ colorval, n = 50) 
 confint(Mustangs.cor.boot)
@@ -231,11 +231,13 @@ do(1) * lm(Price ~ Miles + Age, data = Mustangs)
 
 ## -------------------------------------------------------------------
 Mustangs.Age.boot <- do(1000) * lm(Price ~ Miles + shuffle(Age), data = Mustangs )
-confint(Mustangs.Age.boot)
+favstats(~ r.squared, data = Mustangs.Age.boot)
+cdata(~ r.squared, .95, data = Mustangs.Age.boot)
 
 ## -------------------------------------------------------------------
 Mustangs.Miles.boot <- do(1000) * lm(Price ~ shuffle(Miles) + Age, data = Mustangs)
-confint(Mustangs.Miles.boot)
+favstats(~ r.squared, data = Mustangs.Miles.boot)
+cdata(~ r.squared, .95, data = Mustangs.Miles.boot)
 
 ## -------------------------------------------------------------------
 chisq.test(tally(~ homeless + sex, 
