@@ -41,9 +41,11 @@ test_that("formulas work without data", {
   expect_equivalent( mean( ~ age ), mean( ~age, data=mosaicData::HELPrct ))
 })
 
-test_that("var grabs two vectors from data frame", {
-  expect_equivalent( var( ~age, ~cesd, data=mosaicData::HELPrct ), var( mosaicData::HELPrct$age, mosaicData::HELPrct$cesd) )
-})
+test_that(
+  "var grabs two vectors from data frame", {
+    expect_equivalent(var( ~ age, ~ cesd, data = mosaicData::HELPrct), 
+                      var(mosaicData::HELPrct$age, mosaicData::HELPrct$cesd))
+  })
 
 test_that("na.rm works", {
   x <<- 1:6; y <<- c(1,2,5,6)
@@ -59,7 +61,7 @@ test_that("na.rm works", {
 })
 
 test_that("sum( a + x ) works, etc.", {
-  x <<- 1:6; a <<- 11:16
+  x <- 1:6; a <- 11:16
   expect_equivalent( sum( a + x) , base::sum( a + x) )
   expect_equivalent( mean( a + x) , base::mean( a + x) )
   expect_equivalent( median( a + x) , stats::median( a + x) )
@@ -93,3 +95,13 @@ test_that("var() works.", {
 #                      favstats( ~ age, data = HELPrct) )
 # })
 
+test_that("aggregatingFunctions work", {
+  require(mosaicData)
+  foo <- aggregatingFunction1(base::mean)
+  expect_equivalent(24.7230769230769, foo( ~ length, data = KidsFeet))
+  
+ 
+  foo <- aggregatingFunction2(stats::cor)
+  expect_equivalent(0.641096051081777, foo(length ~ width, data = KidsFeet))
+})
+
